@@ -1,8 +1,10 @@
 #!/usr/bin/env bash
 # This script formats the code of this package
 
+cd ..
+
 echo "Formating import statements..."
-isort ..
+isort
 
 echo "Formating source code..."
-black ..
\ No newline at end of file
+black --config pyproject.toml
\ No newline at end of file
